@@ -1,4 +1,5 @@
 import pytest
+
 from PIL import Image
 
 from .helper import assert_deep_equal, assert_image, hopper
@@ -30,7 +31,7 @@ def test_numpy_to_image():
         return i
 
     # Check supported 1-bit integer formats
-    assert_image(to_image(numpy.bool, 1, 1), "1", TEST_IMAGE_SIZE)
+    assert_image(to_image(bool, 1, 1), "1", TEST_IMAGE_SIZE)
     assert_image(to_image(numpy.bool8, 1, 1), "1", TEST_IMAGE_SIZE)
 
     # Check supported 8-bit integer formats
@@ -64,7 +65,7 @@ def test_numpy_to_image():
         to_image(numpy.int64)
 
     # Check floating-point formats
-    assert_image(to_image(numpy.float), "F", TEST_IMAGE_SIZE)
+    assert_image(to_image(float), "F", TEST_IMAGE_SIZE)
     with pytest.raises(TypeError):
         to_image(numpy.float16)
     assert_image(to_image(numpy.float32), "F", TEST_IMAGE_SIZE)
@@ -89,6 +90,11 @@ def test_3d_array():
     assert_image(Image.fromarray(a[:, :, 1]), "L", TEST_IMAGE_SIZE)
 
 
+def test_1d_array():
+    a = numpy.ones(5, dtype=numpy.uint8)
+    assert_image(Image.fromarray(a), "L", (1, 5))
+
+
 def _test_img_equals_nparray(img, np):
     assert len(np.shape) >= 2
     np_size = np.shape[1], np.shape[0]
@@ -185,7 +191,7 @@ def test_putdata():
 
 def test_roundtrip_eye():
     for dtype in (
-        numpy.bool,
+        bool,
         numpy.bool8,
         numpy.int8,
         numpy.int16,
@@ -193,7 +199,7 @@ def test_roundtrip_eye():
         numpy.uint8,
         numpy.uint16,
         numpy.uint32,
-        numpy.float,
+        float,
         numpy.float32,
         numpy.float64,
     ):
@@ -212,7 +218,7 @@ def test_zero_size():
 
 def test_bool():
     # https://github.com/python-pillow/Pillow/issues/2044
-    a = numpy.zeros((10, 2), dtype=numpy.bool)
+    a = numpy.zeros((10, 2), dtype=bool)
     a[0][0] = True
 
     im2 = Image.fromarray(a)
@@ -228,4 +234,6 @@ def test_no_resource_warning_for_numpy_array():
     with Image.open(test_file) as im:
 
         # Act/Assert
-        pytest.warns(None, lambda: array(im))
+        with pytest.warns(None) as record:
+            array(im)
+        assert not record
