@@ -15,7 +15,6 @@ import os
 import shutil
 import subprocess
 import sys
-import tempfile
 from shlex import quote
 
 from PIL import Image
@@ -106,10 +105,20 @@ class Viewer:
         return self.show_file(self.save_image(image), **options)
 
     def show_file(self, file, **options):
-        """Display the given file."""
+        """Display given file"""
         os.system(self.get_command(file, **options))
         return 1
 
+    def _remove_file_after_delay(self, file):
+        subprocess.Popen(
+            [
+                sys.executable,
+                "-c",
+                "import os, sys, time; time.sleep(20); os.remove(sys.argv[1])",
+                file,
+            ]
+        )
+
 
 # --------------------------------------------------------------------
 
@@ -147,16 +156,8 @@ class MacViewer(Viewer):
 
     def show_file(self, file, **options):
         """Display given file"""
-        fd, path = tempfile.mkstemp()
-        with os.fdopen(fd, "w") as f:
-            f.write(file)
-        with open(path) as f:
-            subprocess.Popen(
-                ["im=$(cat); open -a Preview.app $im; sleep 20; rm -f $im"],
-                shell=True,
-                stdin=f,
-            )
-        os.remove(path)
+        subprocess.call(["open", "-a", "Preview.app", file])
+        self._remove_file_after_delay(file)
         return 1
 
 
@@ -172,19 +173,6 @@ class UnixViewer(Viewer):
         command = self.get_command_ex(file, **options)[0]
         return f"({command} {quote(file)}; rm -f {quote(file)})&"
 
-    def show_file(self, file, **options):
-        """Display given file"""
-        fd, path = tempfile.mkstemp()
-        with os.fdopen(fd, "w") as f:
-            f.write(file)
-        with open(path) as f:
-            command = self.get_command_ex(file, **options)[0]
-            subprocess.Popen(
-                ["im=$(cat);" + command + " $im; rm -f $im"], shell=True, stdin=f
-            )
-        os.remove(path)
-        return 1
-
 
 class XDGViewer(UnixViewer):
     """
@@ -195,6 +183,12 @@ class XDGViewer(UnixViewer):
         command = executable = "xdg-open"
         return command, executable
 
+    def show_file(self, file, **options):
+        """Display given file"""
+        subprocess.Popen(["xdg-open", file])
+        self._remove_file_after_delay(file)
+        return 1
+
 
 class DisplayViewer(UnixViewer):
     """
@@ -208,6 +202,17 @@ class DisplayViewer(UnixViewer):
             command += f" -name {quote(title)}"
         return command, executable
 
+    def show_file(self, file, **options):
+        """Display given file"""
+        args = ["display"]
+        if "title" in options:
+            args += ["-name", options["title"]]
+        args.append(file)
+
+        subprocess.Popen(args)
+        os.remove(file)
+        return 1
+
 
 class GmDisplayViewer(UnixViewer):
     """The GraphicsMagick ``gm display`` command."""
@@ -217,6 +222,12 @@ class GmDisplayViewer(UnixViewer):
         command = "gm display"
         return command, executable
 
+    def show_file(self, file, **options):
+        """Display given file"""
+        subprocess.Popen(["gm", "display", file])
+        os.remove(file)
+        return 1
+
 
 class EogViewer(UnixViewer):
     """The GNOME Image Viewer ``eog`` command."""
@@ -226,6 +237,12 @@ class EogViewer(UnixViewer):
         command = "eog -n"
         return command, executable
 
+    def show_file(self, file, **options):
+        """Display given file"""
+        subprocess.Popen(["eog", "-n", file])
+        os.remove(file)
+        return 1
+
 
 class XVViewer(UnixViewer):
     """
@@ -241,6 +258,17 @@ class XVViewer(UnixViewer):
             command += f" -name {quote(title)}"
         return command, executable
 
+    def show_file(self, file, **options):
+        """Display given file"""
+        args = ["xv"]
+        if "title" in options:
+            args += ["-name", options["title"]]
+        args.append(file)
+
+        subprocess.Popen(args)
+        os.remove(file)
+        return 1
+
 
 if sys.platform not in ("win32", "darwin"):  # unixoids
     if shutil.which("xdg-open"):
